- Added the `strict` argument to `xoutil.records.datetime_reader`:func:.

- You may now install ``xoutil[extra]`` so that not required but useful
  packages are installed when xoutil is installed.

  For now this only includes ``python-dateutil`` that allows the change in
  `~xoutil.records.datetime_reader`:func:.
